@@ -35,6 +35,9 @@ def parser():
                     ind = text.find('г.')
                 text = text[text.find(' ')+1:ind]
                 date = f.get_dig_date(text)
+                if date == -1:
+                    text = text[text.find(":")+1:]
+                    date = f.get_dig_date(text)
                 people.append({
                     'image_link': image_link,
                     'first_name': name[1],
@@ -51,4 +54,7 @@ def parser():
         except:
             return [{'code': 1, 'script': os.path.basename(__file__)}]
     else:
-        return [{'code': 2, 'script': os.path.basename(__file__)}]
\ No newline at end of file
+        return [{'code': 2, 'script': os.path.basename(__file__)}]
+
+if __name__ == "__main__":
+    print(parser())
\ No newline at end of file
